@@ -147,6 +147,7 @@ class BackupManager():
                 print(self.log.colourString(getString("Destination Database Conflicts: %s") % (len(dest_conflicts)), "V"))
                 self.log.printChangedFiles(dest_conflicts, dest_dict, dest_prev, "   Dest", "     DB")
         # print database conflicts concerning CRCs if available, as well as CRC conflicts between source and dest if attributes otherwise match
+        crc_errors_detected = []
         if len(source_crc_errors) > 0 or len(dest_crc_errors) > 0:
             self.log.append([getString("### CRC ERRORS DETECTED ###")], ["Section"])
             print(self.log.colourString(getString("WARNING: found non matching CRC values, possible corruption detected"), "Y"))
@@ -157,6 +158,21 @@ class BackupManager():
                 self.log.printSyncDbConflicts(crc_errors_detected, source_dict, dest_dict, source_prev, dest_prev)
             else:
                 self.log.printChangedFiles(crc_errors_detected, source_dict, source_prev, " Source", "     DB")
+        # show curses tree
+        if self.config.curses:
+            try:
+                from .treeman import dest_conflicts_tree, sync_conflicts_tree
+                self.log.writeLog("database.tmp.json")
+                if dest_database_load_success and self.config.source != self.config.dest:
+                    if self.config.main_mode == "sync":
+                        sync_conflicts_tree(sync_conflicts, crc_errors_detected)
+                    else:
+                        dest_conflicts_tree(dest_new, dest_modified, dest_missing, crc_errors_detected)
+                else:
+                    sync_conflicts_tree([], crc_errors_detected)
+            except Exception:
+                print(self.log.colourString(getString("Curses Error"), "R"))
+                abort_run = True
         return abort_run
 
     def _printAndLogScanOnlyDiffSummary(self, side_str: str, side_info: DirInfo) -> None:
@@ -182,6 +198,14 @@ class BackupManager():
         print(self.log.colourString(getString("%s Moved Files: %s (%s)") % (side_str, len(moved), sum_size), "V"))
         self.log.append([getString("### %s MOVED FILES ###") % (side_str.upper())], ["Section"])
         self.log.printMovedFiles(moved, side_dict, side_prev, "   New: ", "   Old: ")
+        # show curses tree
+        if self.config.curses:
+            try:
+                from .treeman import scan_only_tree
+                self.log.writeLog("database.tmp.json")
+                scan_only_tree(side_str, list_new, list_missing, list_modified, moved)
+            except Exception:
+                print(self.log.colourString(getString("Curses Error"), "R"))
 
     def _printAndLogCompareDiffSummary(self, transfer_lists: TransferLists) -> None:
         # get lists and databases
@@ -334,7 +358,7 @@ class BackupManager():
             return 0
         # wait for go ahead
         self.log.writeLog("database.tmp.json")
-        if not self.config.noprompt:
+        while not self.config.noprompt:
             if self.gui:
                 go = self.gui_simplePrompt(getString("Scan complete, continue with %s%s?") % (self.config.main_mode, simulation_msg))
             else:
@@ -343,8 +367,17 @@ class BackupManager():
             if len(go.strip()) == 4 and go.strip().lower() == "skip":
                 if not transfer_lists.skipFileTransfers(self.log):
                     return self.abortRun()
+            elif len(go.strip()) == 6 and go.strip().lower() == "curses":
+                try:
+                    from .treeman import transfer_lists_tree
+                    transfer_lists_tree(transfer_lists.getLists())
+                except Exception:
+                    print(self.log.colourString(getString("Curses Error"), "R"))
+                    return self.abortRun()
             elif len(go.strip()) == 0 or go.strip()[0].lower() != "y":
                 return self.abortRun()
+            elif go.strip()[0].lower() == "y":
+                break
         # backup operations
         self._performBackup(transfer_lists, simulation_msg)
         self.log.append([getString("### COMPLETED ###")])
